@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2001-2023 Univention GmbH
+# Copyright 2001-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -33,15 +33,16 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, annotations, print_function
+from __future__ import annotations
 
+import functools
+import operator
 import os
+import pickle  # noqa: S403
 import re
 import subprocess
 from typing import Dict, List
-
-from six.moves import cPickle as pickle
-from six.moves.urllib_parse import quote
+from urllib.parse import quote
 
 import univention.debug as ud
 import univention.lib.listenerSharePath
@@ -265,9 +266,9 @@ def handler(dn: str, new: Dict[str, List[bytes]], old: Dict[str, List[bytes]], c
             prev_aces = set()
             new_aces = set()
             if 'univentionShareSambaBaseDirAppendACL' in old:
-                prev_aces = set(sum([RE_ACE.findall(acl.decode('UTF-8')) for acl in old['univentionShareSambaBaseDirAppendACL']], []))
+                prev_aces = set(functools.reduce(operator.iadd, [RE_ACE.findall(acl.decode('UTF-8')) for acl in old['univentionShareSambaBaseDirAppendACL']], []))
             if 'univentionShareSambaBaseDirAppendACL' in new:
-                new_aces = set(sum([RE_ACE.findall(acl.decode('UTF-8')) for acl in new['univentionShareSambaBaseDirAppendACL']], []))
+                new_aces = set(functools.reduce(operator.iadd, [RE_ACE.findall(acl.decode('UTF-8')) for acl in new['univentionShareSambaBaseDirAppendACL']], []))
 
             if (new_aces and new_aces != prev_aces) or (prev_aces and not new_aces):
                 # if old != new -> delete everything from old!
