@@ -1,8 +1,35 @@
 #!/usr/bin/python3
 
 #
-# SPDX-FileCopyrightText: 2011-2026 Univention GmbH
-# SPDX-License-Identifier: AGPL-3.0-only
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# Copyright 2011-2024 Univention GmbH
+#
+# https://www.univention.de/
+#
+# All rights reserved.
+#
+# The source code of this program is made available
+# under the terms of the GNU Affero General Public License version 3
+# (GNU AGPL V3) as published by the Free Software Foundation.
+#
+# Binary versions of this program provided by Univention to you as
+# well as other copyrighted, protected or trademarked materials like
+# Logos, graphics, fonts, specific documentations and configurations,
+# cryptographic keys etc. are subject to a license agreement between
+# you and Univention and not subject to the GNU AGPL V3.
+#
+# In the case you use this program under the terms of the GNU AGPL V3,
+# the program is provided in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public
+# License with the Debian GNU/Linux or Univention distribution in file
+# /usr/share/common-licenses/AGPL-3; if not, see
+# <https://www.gnu.org/licenses/>.
 
 # This script was adjusted from the Tests for ntacls manipulation
 # Copyright (C) Matthieu Patou <mat@matws.net> 2009-2010
@@ -20,8 +47,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
-
-"""Set user_xattr option on ext2/ext3/ext4 filesystems, remount if necessary"""
+"""Set user_xattr option on ext3/ext4 filesystems, remount if necessary"""
 
 
 import subprocess
@@ -57,9 +83,9 @@ def _modify_extfs_option(options=[], activate=True, devices=[]):
             if fstab_partition and fstab_partition.type in ('ext3', 'ext4'):
                 target_partitions.append(fstab_partition)
             else:
-                print('Device could not be found: %s' % device)
+                print('Device could not be found: %s' % (device,))
     else:
-        for fstype in ('ext2', 'ext3', 'ext4'):
+        for fstype in ('ext3', 'ext4'):
             for fstab_partition in fs.get(fstype, ignore_root=False):
                 target_partitions.append(fstab_partition)  # noqa: PERF402
 
@@ -67,7 +93,7 @@ def _modify_extfs_option(options=[], activate=True, devices=[]):
         if _do_modify_extfs_option(fstab_partition, options, activate):
             fs.save()
             if subprocess.call(('mount', '-o', 'remount', fstab_partition.spec)):
-                print('Remounting partition failed: %s' % fstab_partition.spec)
+                print('Remounting partition failed: %s' % (fstab_partition.spec,))
 
 
 if __name__ == '__main__':
